@@ -1,6 +1,10 @@
-package OpenGbg;
-$OpenGbg::VERSION = '0.1300';
 use 5.14.0;
+use strict;
+use warnings;
+package OpenGbg;
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: An interface to the Open Data API of Gothenburg
 
 use OpenGbg::Handler;
 
@@ -13,13 +17,17 @@ sub new {
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
 OpenGbg - An interface to the Open Data API of Gothenburg
 
-=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-OpenGbg"><img src="https://travis-ci.org/Csson/p5-OpenGbg.svg?branch=master">&nbsp;</a>
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -84,25 +92,27 @@ All calls to services are prefixed with 'get' even if the service isn't named th
 
 Date/time intervals are always called 'start' and 'end' (in the web services they are sometimes called 'start' and 'stop').
 
-=head1 BUGS & ISSUES
-
-The repository and issue tracker is at: L<https://github.com/Csson/p5-OpenGbg>
-
 =head1 DISCLAIMER
 
 This is not an official distribution.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
