@@ -1,13 +1,17 @@
-use 5.10.0;
+use 5.14.0;
+use strict;
 use warnings;
 
 # Insired by Throwable::X
 package OpenGbg::Exception {
-$OpenGbg::Exception::VERSION = '0.1300';
-use Moose::Role;
+
+    our $VERSION = '0.1301'; # VERSION
+    # ABSTRACT: Exception role
+
+    use Moose::Role;
     use Throwable::X::Types;
 
-    use namespace::clean -except => 'meta';
+    use namespace::autoclean -except => 'meta';
 
     use Sub::Exporter -setup => {
         exports => { Payload => \'__payload' },
@@ -44,11 +48,17 @@ use Moose::Role;
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Exception - When something fails
+OpenGbg::Exception - Exception role
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -100,17 +110,23 @@ Dies.
         }
     };
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
