@@ -1,4 +1,7 @@
-use OpenGbg::Standard::Moops;
+use OpenGbg::Standard::Imports;
+
+our $VERSION = '0.1301'; # VERSION
+# PODNAME: OpenGbg::Handler
 
 class OpenGbg::Handler
 using Moose {
@@ -93,11 +96,17 @@ using Moose {
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Handler - The entry point to all OpenGbg services.
+OpenGbg::Handler
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -112,32 +121,35 @@ OpenGbg::Handler is the class from where calls to all web services are made.
 
 =head1 METHOD
 
-
 =head2 air_quality()
 
 Returns a L<OpenGbg::Service::AirQuality> object.
 
-
 =head2 bridge()
 
 Returns a L<OpenGbg::Service::Bridge> object.
 
-
 =head2 styr_och_stall()
 
 Returns a L<OpenGbg::Service::StyrOchStall> object.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
