@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::AirQuality::GetLatestMeasurement;
-$OpenGbg::Service::AirQuality::GetLatestMeasurement::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: Get the latest air quality measurement
+
 use OpenGbg::Types -types;
 use Kavorka;
 use XML::Rabbit::Root;
@@ -24,11 +29,17 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Service::AirQuality::GetLatestMeasurement
+OpenGbg::Service::AirQuality::GetLatestMeasurement - Get the latest air quality measurement
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -43,17 +54,23 @@ OpenGbg::Service::AirQuality::GetLatestMeasurement
 
 Returns the L<OpenGbg::Service::AirQuality::Measurement> object given in the response  (usually less than an hour old).
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
