@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::AirQuality::GetMeasurements;
-$OpenGbg::Service::AirQuality::GetMeasurements::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: Get a collection of measurements
+
 use OpenGbg::Types -types;
 use XML::Rabbit::Root;
 use DateTime::Format::HTTP;
@@ -24,11 +29,17 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Service::AirQuality::GetMeasurements
+OpenGbg::Service::AirQuality::GetMeasurements - Get a collection of measurements
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -37,24 +48,33 @@ OpenGbg::Service::AirQuality::GetMeasurements
 
     print $response->measurements->get_by_index(5)->to_text;
 
+=head1 NAME
+
+OpenGbg::Service::AirQuality::GetMeasurements
+
 =head1 METHODS
 
 =head2 measurements
 
 Returns the list of measurements in the response in a L<OpenGbg::Service::AirQuality::Measurements> object.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
 
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
