@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::AirQuality::Measurement;
-$OpenGbg::Service::AirQuality::Measurement::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: An air quality measurement
+
 use utf8;
 use syntax 'qs';
 use XML::Rabbit;
@@ -245,12 +250,10 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
-=head1 NAME
-
-OpenGbg::Service::AirQuality::Measurement - An air quality measurement
-
 =head1 SYNOPSIS
 
     my $service = OpenGbg->new->air_quality;
@@ -343,24 +346,45 @@ The amount of particulates (less than 10 micrometers) in the air.
 
 The amount of sulfur dioxide in the air.
 
-
 =head1 METHODS
 
 =head2 to_text()
 
 Returns a string with the station data in a table.
 
+=cut
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+OpenGbg::Service::AirQuality::Measurement - An air quality measurement
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
