@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::AirQuality::Measurements;
-$OpenGbg::Service::AirQuality::Measurements::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: A list of air quality measurements
+
 use XML::Rabbit;
 use Kavorka;
 
@@ -22,12 +27,18 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
 OpenGbg::Service::AirQuality::Measurements - A list of air quality measurements
 
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
+
 =head1 SYNOPSIS
 
     my $service = OpenGbg->new->air_quality;
@@ -66,24 +77,29 @@ Eg, to get the total solar insolation:
     use List::AllUtils 'sum';
     my $total_solar_insolation_per_m2 = sum $response->measurements->map( sub { $_->solar_insolation });
 
-
 =head2 sort(sub { ... })
 
 Like C<filter> it takes a sub routine reference. It works just like C<sort> except the two L<Measurement|OpenGbg::Service::AirQuality::Measurement> objects to compare are passed as C<$_[0]> and C<$_[1]>
 
     my @hottest_hours_first = $response->measurements->sort( sub { $_[1]->temperature <=> $_[0]->temperature });
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
