@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::Bridge::BridgeOpenings;
-$OpenGbg::Service::Bridge::BridgeOpenings::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: A list of bridge openings/closings
+
 use XML::Rabbit;
 use Kavorka;
 
@@ -22,11 +27,17 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Service::Bridge::BridgeOpenings - A list of open/closed statuses for Göta älvbron
+OpenGbg::Service::Bridge::BridgeOpenings - A list of bridge openings/closings
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -71,17 +82,23 @@ Like C<filter> it takes a sub routine reference and passes each L<BridgeOpening|
 
 Like C<filter> it takes a sub routine reference. It works just like C<sort> except the two L<BridgeOpening|OpenGbg::Service::Bridge::BridgeOpening> objects to compare are passed as C<$_[0]> and C<$_[1]>
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
