@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::StyrOchStall::GetBikeStation;
-$OpenGbg::Service::StyrOchStall::GetBikeStation::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: Get data about a bike station
+
 use OpenGbg::Types -types;
 use Kavorka;
 use XML::Rabbit::Root;
@@ -41,11 +46,17 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Service::StyrOchStall::GetBikeStation
+OpenGbg::Service::StyrOchStall::GetBikeStation - Get data about a bike station
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -65,18 +76,23 @@ Returns the timestamp given in the response as a L<DateTime> object.
 
 Returns the L<OpenGbg::Service::StyrOchStall::Station> object given in the response.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
 
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
