@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::TrafficCamera::CameraDevice;
-$OpenGbg::Service::TrafficCamera::CameraDevice::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: Data about a traffic camera
+
 use XML::Rabbit;
 use syntax 'qs';
 use Kavorka;
@@ -39,11 +44,17 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Service::TrafficCamera::CameraDevice - A traffi camera
+OpenGbg::Service::TrafficCamera::CameraDevice - Data about a traffic camera
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -54,7 +65,6 @@ OpenGbg::Service::TrafficCamera::CameraDevice - A traffi camera
     my $camera_device = $camera_devices->get_by_index(0)
     print $camera_device->to_text;
 
-
 =head1 ATTRIBUTES
 
 =head2 id
@@ -77,24 +87,29 @@ Integer. How long between captures.
 
 String. The brand and/or model of the traffic camera.
 
-
 =head1 METHODS
 
 =head2 to_text()
 
 Returns a string with the traffic camera data in a table.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
