@@ -1,7 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package OpenGbg::Service::TrafficCamera::GetTrafficCameras;
-$OpenGbg::Service::TrafficCamera::GetTrafficCameras::VERSION = '0.1300';
+
+our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: Get a list of traffic cameras
+
 use OpenGbg::Types -types;
 use XML::Rabbit::Root;
 use MooseX::AttributeShortcuts;
@@ -23,11 +28,17 @@ finalize_class();
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-OpenGbg::Service::TrafficCamera::GetTrafficCameras
+OpenGbg::Service::TrafficCamera::GetTrafficCameras - Get a list of traffic cameras
+
+=head1 VERSION
+
+Version 0.1301, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -42,17 +53,23 @@ OpenGbg::Service::TrafficCamera::GetTrafficCameras
 
 Returns the list of traffic cameras in the response in a L<OpenGbg::Service::TrafficCamera::CameraDevices> object.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-OpenGbg>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/OpenGbg>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
